# Didipack
This package contains simple functions that help organize code and produce results for quantitative research in finance and econ. 

Functionalities include dynamic management of project parameters and organization of output in latex tables and projects. 

## Installation
pip install didipack

## latex table
The first functionality concerns latex tables. The demo_latex.py file contains an illustration/tutorial on these functions. 

After running the demo_latex.py file, you can compile the tex_example/main.tex file to see the example.

## Paper
The second functionality helps create full latex projects organized in sections and imitating the format of the journal of finance. 

The code in demo_paper.py shows how the didipack can create such a project and populate it with tex, figures, and tables, all from python code only.

## parameters
This function is here to create a basis for the parameters class of the whole project. 

The demo_params.py file contains an illustration/tutorial on how to use the params class in your projects. 
